@@ -135,6 +135,51 @@ def override_logging(based_on: Optional[AnastasiaLogger] = None) -> None:
     logging.basicConfig(filename=filename, format=format, datefmt=datefmt, level=level)
     logging.info("Root logging modified with AnastasiaLogger structure")
 
+def debug(msg: Optional[str] = None, code: Optional[int] = None, save_log: bool = False, return_formatted_msg: bool = False, *args, **kwargs) -> Optional[str]:
+    """
+    Inherited from logging.debug function with additional properties
+
+    Attributes
+    ----------
+
+    msg : Optional[str], default=None
+        Name identification of logger instance
+
+    code : Optional[int], default=None
+        Code assignation to add, if msg is not declared then it will search for default debug codes
+
+    save_log : bool, default=False
+        Force to save log file, predefined with log_path attribute
+
+    return_formatted_msg : bool = False
+        If True, return the formatted message for further usage as a string
+
+    *args, **kwargs inherited from logging.debug function
+
+    Returns
+    -------
+
+    formatted_msg : Optional[str]
+        Message formatted with logger definitions
+
+    Notes
+    -----
+
+    Base codes standards:
+
+    -   0 = Unindentified
+    - 1XX = Data related
+    - 2XX = Mathematical related
+    - 3XX = AI related
+    - 4XX = Resources related
+    - 5XX = Operative System (OS) related
+    - 6XX = API related
+    - 7XX = AWS related
+
+    """
+
+    return anastasia_logger.debug(msg=msg, code=code, save_log=save_log, return_formatted_msg=return_formatted_msg, *args, **kwargs)
+
 def info(msg: Optional[str] = None, code: Optional[int] = None, save_log: bool = False, return_formatted_msg: bool = False, *args, **kwargs) -> Optional[str]:
     """
     Inherited from logging.info function with additional properties
@@ -273,6 +318,56 @@ def error(msg: Optional[str] = None, code: Optional[int] = None, raise_type: Opt
     
     return anastasia_logger.error(msg=msg, code=code, raise_type=raise_type, save_log=save_log, return_formatted_msg=return_formatted_msg, *args, **kwargs)
 
+def critical(msg: Optional[str] = None, code: Optional[int] = None, raise_type: Optional[type] = None, save_log: bool = False, return_formatted_msg: bool = False, *args, **kwargs) -> Optional[str]:
+    """
+    Inherited from logging.critical function with additional properties
+
+    Attributes
+    ----------
+
+    msg : Optional[str], default=None
+        Name identification of logger instance
+
+    code : Optional[int], default=None
+        Code assignation to add, if msg is not declared then it will search for default critical codes
+
+    raise_type : Optional[type], default=None
+        Raise any type with message content as text description and terminating python script execution, if None then no python type will be raised
+
+    save_log : bool, default=False
+        Force to save log file, predefined with log_path attribute
+
+    return_formatted_msg : bool = False
+        If True, return the formatted message for further usage as a string
+
+    *args, **kwargs inherited from logging.critical function
+
+    Returns
+    -------
+
+    formatted_msg : str
+            Message formatted with logger definitions
+
+    Notes
+    -----
+
+    Base codes standards:
+
+    -   0 = Unindentified
+    - 1XX = Data related
+    - 2XX = Mathematical related
+    - 3XX = AI related
+    - 4XX = Resources related
+    - 5XX = Operative System (OS) related
+    - 6XX = API related
+    - 7XX = AWS related
+
+    """
+    
+    return anastasia_logger.critical(msg=msg, code=code, raise_type=raise_type, save_log=save_log, return_formatted_msg=return_formatted_msg, *args, **kwargs)
+
+fatal = critical # fatal = critical in base logging implementation
+
 def print(msg: Optional[str] = None, code: Optional[int] = None, return_formatted_msg: bool = False, *args, **kwargs) -> Optional[str]:
     """
     Show in console a required message with logger format, doesn't register in contained handlers (just for console view, like a normal python print). 
